@@ -2,9 +2,7 @@
 # Copyright 2017 Roger Marsh
 # License: See LICENSE.TXT (BSD licence)
 
-"""Universal Chess Interface (UCI) communication with chess engine driver.
-
-"""
+"""Universal Chess Interface (UCI) communication with chess engine driver."""
 
 import sys
 from urllib.parse import urlsplit
@@ -13,9 +11,7 @@ from .uci_driver import UCIDriver
 
 
 class UCIDriverOverTCP(UCIDriver):
-    """Implement communication with chess engine processes.
-
-    """
+    """Implement communication with chess engine processes."""
 
     def insert_remote_hostname_port(self, args):
         """Prepend args with tcp_client command if args[0] has hostname or port.
@@ -30,10 +26,18 @@ class UCIDriverOverTCP(UCIDriver):
         """
         url = urlsplit(args[0])
         if url.port or url.hostname:
-            args.insert(0, 'uci_net.tcp_client')
-            args.insert(0, '-m')
+            args.insert(0, "uci_net.tcp_client")
+            args.insert(0, "-m")
             args.insert(
                 0,
-                ''.join(('python',
-                         ('' if sys.platform == 'win32' else
-                          '.'.join(str(e) for e in sys.version_info[:2])))))
+                "".join(
+                    (
+                        "python",
+                        (
+                            ""
+                            if sys.platform == "win32"
+                            else ".".join(str(e) for e in sys.version_info[:2])
+                        ),
+                    )
+                ),
+            )
